# Uniq Calc

This package will help you Calculate Numbers Quickly.

## How to Install it?

## On Windows

```
pip install uniqcalc
```

## On Linux:

```
sudo pip3 install uniqcalc
```

## How to use it?

### Initializing Package
```
from uniqcalc import UniqCalc

num_1 = 8
num_2 = 1

calc = UniqCalc(num_1, num_2)
```

### Adding Numbers
```
calc.addition()
```

### Substracting Numbers
```
calc.substraction()
```

### Multiplying Numbers
```
calc.multiplication()
```

### Dividing Numbers
```
calc.division()
```